@@ -25,7 +25,7 @@ ensure_bitarray(PyObject *obj)
     if (t < 0)
         return -1;
     if (t == 0) {
-        PyErr_Format(PyExc_TypeError, "bitarray expected, not %s",
+        PyErr_Format(PyExc_TypeError, "bitarray expected, not '%s'",
                      Py_TYPE(obj)->tp_name);
         return -1;
     }
@@ -1824,7 +1824,7 @@ chdi_new(PyObject *module, PyObject *args)
     Py_ssize_t count_sum;
     chdi_obj *it;       /* iterator object to be returned */
 
-    if (!PyArg_ParseTuple(args, "O!OO:count_n",
+    if (!PyArg_ParseTuple(args, "O!OO:canonical_decode",
                           bitarray_type_obj, &a, &count, &symbol))
         return NULL;
     if (!PySequence_Check(count))
